#define DECLARE_TEXTURE(Name, index) \
    texture Name: register(t##index); \
    sampler Name##Sampler: register(s##index)

#define SAMPLE_TEXTURE(Name, texCoord) tex2D(Name##Sampler, texCoord)

uniform float Time; // level.TimeActive
uniform float2 CamPos; // level.Camera.Position
uniform float2 Dimensions; // new Vector2(320, 180)

uniform float4x4 TransformMatrix;
uniform float4x4 ViewMatrix;

DECLARE_TEXTURE(text, 0);

float length(float2 pos, float t) {
    return saturate(sin(pos.x/Dimensions.x + pos.y/Dimensions.y + (frac(Time/8.0+t))*6.283185));
}


float4 SpritePixelShader(float2 uv : TEXCOORD0) : COLOR0
{
    float2 center = float2(.5,.5);
    float2 worldPos = (uv * Dimensions) + CamPos;
    float2 worldPosB = ((uv+0.3) * Dimensions) + CamPos;
    float4 color = SAMPLE_TEXTURE(text, uv);
    float timeScaled = Time * .35;

    float threshhold = 0.02;
    if(color.r < threshhold && color.g < threshhold && color.b < threshhold)
    {
        return (0.0,0.0,0.0,0.0);
    }

    color.r = frac(length(worldPos, 0.0));
    color.b = frac(length(worldPos, 0.33));
    color.g = frac(length(worldPos, 0.66));

    return color;

}

void SpriteVertexShader(inout float4 color    : COLOR0,
                        inout float2 texCoord : TEXCOORD0,
                        inout float4 position : SV_Position)
{
    position = mul(position, ViewMatrix);
    position = mul(position, TransformMatrix);
}

technique Shader
{
    pass pass0
    {
        VertexShader = compile vs_3_0 SpriteVertexShader();
        PixelShader = compile ps_3_0 SpritePixelShader();
    }
}